@@ -1,7 +1,7 @@
 use cid::Cid;
+use fvm_ipld_blockstore::Blockstore;
 use fvm_shared::actor::builtin::Manifest;
 use fvm_shared::address::Address;
-use fvm_shared::blockstore::Blockstore;
 use fvm_shared::clock::ChainEpoch;
 use fvm_shared::econ::TokenAmount;
 use fvm_shared::version::NetworkVersion;
